@@ -1,4 +1,4 @@
-# $Id: testcase.rb,v 1.11 2002/12/25 06:39:54 yuya Exp $
+# $Id: testcase.rb,v 1.12 2003/01/10 05:08:22 yuya Exp $
 
 require 'test/unit/testcase'
 
@@ -26,7 +26,7 @@ class ExerbTestCase < Test::Unit::TestCase
 
   def make_mak(basename, files)
     corename = 'ruby168c'
-    corefile = "../project/#{corename}/release/#{corename}.exe"
+    corefile = "../project/#{corename}/release/#{corename}.rbx"
 
     File.open(basename + '.mak', 'w') { |file|
       file.puts "all: #{basename}.exe"
